@@ -180,10 +180,12 @@
 pub mod basic;
 pub mod basic_multi_key;
 mod common;
-pub mod merkle;
 pub mod versioned;
 pub mod versioned_multi_key;
 
+#[cfg(feature = "merkle")]
+pub mod merkle;
+
 pub use basic::{mapx::Mapx, mapx_ord::MapxOrd, vecx::Vecx};
 pub use versioned::{mapx::MapxVs, mapx_ord::MapxOrdVs, orphan::OrphanVs, vecx::VecxVs};
 
@@ -192,8 +194,11 @@ pub use versioned_multi_key::{
 };
 
 pub use versioned::VsMgmt;
+
+#[cfg(feature = "derive")]
 pub use vsdb_derive::Vs;
 
+#[cfg(feature = "merkle")]
 pub use merkle::MerkleTree;
 
 pub use common::{
